@@ -39,6 +39,7 @@ See file COPYING for restrictions on the use of this software.
 #include <stdio.h>
 #include <string.h>
 #include <syslog.h>
+#include <unistd.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
 
@@ -184,8 +185,8 @@ static int read_timeout_lock(
 	if (debugmode) {
 	    if (timeout_lock) {
 		syslog(LOG_DEBUG,
-			"%s: waiting %lu seconds for lockfile",
-			source, timeout_lock);
+			"%s: waiting %lu second%s for lockfile",
+			source, timeout_lock, PLURAL(timeout_lock));
 	    } else {
 		syslog(LOG_DEBUG,
 			"%s: waiting indefinitely for lockfile", source);
@@ -248,8 +249,8 @@ readconfig(int logtostderr)
 		if (p) {
 		    p->timeout = atoi(value);
 		    if (debugmode)
-			syslog(LOG_DEBUG, "config: timeout is %d seconds",
-			       p->timeout);
+			syslog(LOG_DEBUG, "config: timeout is %d second%s",
+			       p->timeout, PLURAL(p->timeout));
 		} else
 		    syslog(LOG_ERR, "config: no server for timeout");
 	    } else if (strcmp("allowSTRANGERS", param) == 0) {
@@ -278,7 +279,7 @@ readconfig(int logtostderr)
 		expiredays = i;
 		expire = time(NULL) - (time_t) (SECONDS_PER_DAY * i);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: expire is %d days", i);
+		    syslog(LOG_DEBUG, "config: expire is %d day%s", i, PLURAL(i));
 	    } else if (strcmp("newsadmin", param) == 0) {
 		if (debugmode)
 		    syslog(LOG_DEBUG, "config: newsadmin is %s", value);
@@ -304,8 +305,8 @@ readconfig(int logtostderr)
 		/* maxgroups is for compatibility with leafnode+ */
 		crosspostlimit = strtol(value, NULL, 10);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: crosspostlimit is %ld groups",
-			   crosspostlimit);
+		    syslog(LOG_DEBUG, "config: crosspostlimit is %ld group%s",
+			   crosspostlimit, PLURAL(crosspostlimit));
 	    } else if (strcmp("article_despite_filter", param) == 0) {
 		article_despite_filter = atoi(value) ? 1 : 0;
 		if (debugmode)
@@ -319,18 +320,19 @@ readconfig(int logtostderr)
 	    } else if (strcmp("maxlines", param) == 0) {
 		maxlines = strtol(value, NULL, 10);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: postings have max. %ld lines",
-			   maxlines);
+		    syslog(LOG_DEBUG, "config: postings have max. %ld line%s",
+			   maxlines, PLURAL(maxlines));
 	    } else if (strcmp("minlines", param) == 0) {
 		minlines = strtol(value, NULL, 10);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: postings have min. %ld lines",
-			   minlines);
+		    syslog(LOG_DEBUG, "config: postings have min. %ld line%s",
+			   minlines, PLURAL(minlines));
 	    } else if (strcmp("maxbytes", param) == 0) {
 		maxbytes = strtoul(value, NULL, 10);
 		if (debugmode)
 		    syslog(LOG_DEBUG,
-			   "config: postings have max. %lu bytes", maxbytes);
+			   "config: postings have max. %lu byte%s",
+			   maxbytes, PLURAL(maxbytes));
 	    } else if (strcmp("linebuffer", param) == 0) {
 		linebuffer = atoi(value);
 		if (debugmode)
@@ -359,28 +361,28 @@ readconfig(int logtostderr)
 	    } else if (strcmp("timeout_short", param) == 0) {
 		timeout_short = atoi(value);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: timeout_short is %d days",
-			   timeout_short);
+		    syslog(LOG_DEBUG, "config: timeout_short is %d day%s",
+			   timeout_short, PLURAL(timeout_short));
 	    } else if (strcmp("timeout_long", param) == 0) {
 		timeout_long = atoi(value);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: timeout_long is %d days",
-			   timeout_long);
+		    syslog(LOG_DEBUG, "config: timeout_long is %d day%s",
+			   timeout_long, PLURAL(timeout_long));
 	    } else if (strcmp("timeout_active", param) == 0) {
 		timeout_active = atoi(value);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: timeout_active is %d days",
-			   timeout_active);
+		    syslog(LOG_DEBUG, "config: timeout_active is %d day%s",
+			   timeout_active, PLURAL(timeout_active));
 	    } else if (strcmp("timeout_client", param) == 0) {
 		timeout_client = atoi(value);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: timeout_client is %d secs",
-			   timeout_client);
+		    syslog(LOG_DEBUG, "config: timeout_client is %d second%s",
+			   timeout_client, PLURAL(timeout_client));
 	    } else if (strcmp("timeout_fetchnews", param) == 0) {
 		timeout_fetchnews = atoi(value);
 		if (debugmode)
-		    syslog(LOG_DEBUG, "config: timeout_fetchnews is %d secs",
-			   timeout_fetchnews);
+		    syslog(LOG_DEBUG, "config: timeout_fetchnews is %d second%s",
+			   timeout_fetchnews, PLURAL(timeout_fetchnews));
 	    } else if (strcmp("timeout_lock", param) == 0) {
 		read_timeout_lock(value, "config");
 	    } else if (strncmp("groupexpire", param, 11) == 0) {
@@ -407,8 +409,8 @@ readconfig(int logtostderr)
 			       m);
 			} else
 			    syslog(LOG_DEBUG,
-			           "config: groupexpire for %s is %ld days",
-			           m, (long)i);
+			           "config: groupexpire for %s is %ld day%s",
+			           m, (long)i, PLURAL(i));
 		    }
 		    e = time(NULL) - (time_t) (SECONDS_PER_DAY * i);
 		    ent = (struct expire_entry *)
@@ -639,6 +641,15 @@ readconfig(int logtostderr)
     }
 
     validatefqdn(logtostderr);
+
+    if (debugmode && verbose) {
+	puts("");
+	puts("WARNING:  Make sure that syslog.conf captures news.debug logging");
+	puts("--------  and obtain your debug output from syslog.");
+	puts("WARNING:  The screen output below is not sufficient. Check syslog!");
+	puts("");
+	sleep(3);
+    }
     return 1;
 }
 
