@@ -11,5 +11,5 @@ int mysigact(int sig, int flags, RETSIGTYPE (* func)(int), int blockthis)
     sigemptyset(&sa.sa_mask);
     if (blockthis)
 	sigaddset(&sa.sa_mask, blockthis);
-    return sigaction(sig, &sa, (void *)0);
+    return sigaction(sig, &sa, (struct sigaction *)0);
 }
