@@ -422,11 +422,11 @@ dogroup(/*@null@*/ struct newsgroup *g, const char *name, int expdays)
 	g->last = last;
 
     if (!quiet)
-	printf("%s: %d articles deleted (%lu duplicates), %d kept\n",
-		name, deleted, dupli, kept);
+	printf("%s: %d article%s deleted (%lu duplicate%s), %d kept\n",
+		name, deleted, PLURAL(deleted), dupli, PLURAL(dupli), kept);
     syslog(LOG_INFO,
-	    "%s: %d articles deleted (%lu duplicates), %d kept",
-	    name, deleted, dupli, kept);
+	    "%s: %d article%s deleted (%lu duplicate%s), %d kept",
+	    name, deleted, PLURAL(deleted), dupli, PLURAL(dupli), kept);
 
     if (!kept) {
 	if (unlink(".overview") < 0)
@@ -663,8 +663,8 @@ expiremsgid(void)
 	puts("Done.");
 
     if (!quiet)
-	printf("total: %d articles deleted, %d kept\n", deleted, kept);
-    syslog(LOG_INFO, "%d articles deleted, %d kept", deleted, kept);
+	printf("message.id/: %d article%s deleted, %d kept\n", deleted, PLURAL(deleted), kept);
+    syslog(LOG_INFO, "message.id/: %d article%s deleted, %d kept", deleted, PLURAL(deleted), kept);
 }
 
 
